#include <QtGui>

QStringList splitCSVLine(const QString& line)
{
  int inItem = false;
  QStringList items;
  QString item;

  for (int pos = 0; pos < line.length(); pos++)
  {
    QChar c = line.at(pos);
    if ( c == '\"') {
      if (inItem) {
        items.append(item);
        item = "";
      }
      inItem = !inItem;
    }
    else 
      if (inItem)
         item += c;
  }
  return items;
}
int main(int argc, char* argv[])
{
  QApplication app(argc, argv);

  // Datei ffnen
  QFile file("addressbook.csv");
  if ( !file.open(QIODevice::ReadOnly|QIODevice::Text) )
	  return 1;
  // Adressen auslesen und zeilenweise in Stringliste einlesen
  QString addresses = QString::fromUtf8(file.readAll());
  QStringList records = addresses.split('\n');

  // Erste Zeile (berschriften) entnehmen und aufspalten
  QString header = records.takeAt(0);
  QStringList headers = splitCSVLine(header);

  // Modell anlegen mit Zeilen und Spalten als Argumente
  QStandardItemModel model(records.count(), headers.count());
  
  // berschriften einfgen
  for (int col=0;col<headers.count(); col++) {
     model.setHeaderData(col, Qt::Horizontal, headers.at(col));
  }

  // Inhalte einfgen  
  for (int recNo=0;recNo<records.count(); recNo++) {
     QStringList cells = splitCSVLine(records.at(recNo));
     for (int col=0;col<cells.count(); col++) {
        QModelIndex index = model.index(recNo, col, QModelIndex());
        model.setData(index, cells.at(col));
     }
  }

  // Modell anlegen, Modell setzen und anzeigen
  QTreeView treeView;
  treeView.setWindowTitle(QObject::tr("Addressbook via QStandardItemModel"));
  treeView.setModel(&model);
  treeView.show();

  return app.exec();
}
